C
C     --------------------------
      SUBROUTINE Show_Prm (WHAT)
C UTIDE * Show current set of earth parameters
C     --------------------------
C>
C Show / set / retrieve  model parameters (not: WAHR's elastic earth model).
C
C Show: CALL Show_Prm (model)
C
C MODEL  - character*4 - Identifier
C               'IERS' - CALC / IERS simulation (a.o. tide bulge lag angle);
C               'ANEL' - Anelastic model;
C               'NDR ' - Nearly diurnal resonance (liquid core);
C               'SHDO' - Love number ratios vs. degree and order.
C               'WAHR' - elliptic earth, displacements and strain.
C
C Set: CALL IERSnn (parameters) for tide lag;
C      CALL AELnnn (parameters) for AnELasticitY model;
C      CALL NDRnnn (parameters) for Nearly Diurnal Resonance model;
C      CALL SHDOnn (parameters) for Spherical Harmonic Degree and Order
C                               response model (Love numbers and their ratios).
C      CALL WAHRPM ('nn',parameters) for displacements, strain, and free space
C                               potential;
C
C Reset to default: Use CALL GET_xxxyyy (parameters) to catch the currently
C      used parameter (=default value), change the value using
C      CALL xxxyyy (new parameters),  and reset using
C      CALL xxxyyy (stored-away parameters).
C
C Much more help ...
C_
C Procedures with a GET_ counterpart are indicated by a preceeding '_'
C_____________________________________________________________________________
C
C NAME and                Parameter setting calls
C suffix                                                      Show_Prm - code
C_____________________________________________________________________________
C
C_WAHRPM ('nn',L,F)           (Ell. earth param., displcm., strain)  WAHR
C nn   Parameters        Meaning
C
C W0   L      = {0,1,2}
C      F      - real*8 - (rescaled) parameter w+
C
C W1   L      - unused
C      F      - real*8 - resonance strength for w+
C
C L0   L      = {0,1,2}
C      F      - real*8 - (rescaled) parameter l+
C
C L1   L      - unused
C      F      - real*8 - resonance strength for l+
C
C Z0   L      = {0,1,2}
C      F      - real*8 - (rescaled) parameter z
C
C Z1   L      - unused
C      F      - real*8 - resonance strength for z
C
C Y    L      - unused
C      F      - real*8 - (rescaled) parameter y
C
C S3   L      - unused
C      F      - real*8 - parameter S3 (strain)
C
C_____________________________________________________________________________
C
C IERSnn                          (IERS-VLBI tides simulation)       IERS
C nn   Parameters        Meaning
C
C_LG   F      - real*8 - Lag angle (CALC-fake) in degrees
C
C_H    F      - real*8 - Love number h
C
C_DH   F      - real*8 - Love number difference h(K1) - h
C
C_L    F      - real*8 - Love number l
C_____________________________________________________________________________
C
C AELnnn                              (Anelasticity)                  ANEL
C nnn  Parameters         Meaning
C
C BSF  F      - real*8  - Basic frequency (rad/h)
C      C - character*12 - Comment on BSF, e.g. ' M2 - tide  '
C
C F0   F      - real*8  - Reference frequency (rad/h); default: 1 cyc/y
C
C_CAL  L      - integer - Component code
C      F      - real*8  - Calibration frequency (rad/h); default: Mf
C      G      - real*8  - Total anelastic relaxation amplitude; ratio
C                         of response at CAL-F w.r.t. BSF-F.
C
C_PH0  L      - integer - Component code
C      F      - real*8  - Phase at Reference frequency (rad)
C
C_BRP  F      - real*8  - Breakpoint period (no.of cycles of F0).
C
C_PWP  L      - integer - Component code
C      F      - real*8  - Power law exponent for the phase model.
C
C Component codes: L= 0 - Radial displacement
C                     1 - Tangential displacement
C                     2 - Secondary potential
C_____________________________________________________________________________
C
C NDRmmm                               (Nearly Diurnal Resonance)      NDR
C mmm  Parameters         Meaning
C
C_FRQ  F      - real*8  - NDR period parameter, days per cycle offset from
C                         siderial rotation rate.
C
C REF  F      - real*8  - Reference frequency for the NDR-formulas in rad/h.
C                         Default = O1.
C
C_QUA  F      - real*8  - Quality of the resonance
C
C_BTS  L      - integer - Component code
C      F      - real*8  - NDR-strength, solid earth tide part.
C
C_OSE  L      - integer - Component code
C      Z   - complex*16 - NDR-strength, ocean-solid earth interaction.
C_____________________________________________________________________________
C
C SHDOpp                              (Spheric.harmon.degree & order)  SHDO
C pp   Parameters         Meaning
C
C_H    M,N    - integer - degree, order
C      F      - real*8  - Love number ratio H(M,N) / H(2,1)
C
C_L    M,N
C_K    M,N
C      F      - equivalent for Love numbers L and K
C
C_BL   L      - integer - component code (0,1,2)
C      F      - real*8  - Basic Love number BL = BL(n=2,m=1) frequ.independent.
C_____________________________________________________________________________
C
C Using these setting routines you can compute derivatives of the tide effect
C w r t a specific model parameter.
C
      IMPLICIT REAL*8 (A-H,O-Y), COMPLEX*16 (Z)
      LOGICAL         LCALL
      CHARACTER*4     WHAT, WANEL, WCORE, WSHDO, WIERS, WWAHR
      CHARACTER*12    COMBSF,COMP,COMM
      CHARACTER*2     KIND
      COMMON /MPAR/   PI,RAD
      COMMON /IERSPA/ HIERS,DLQCK1,LIERS,LAG
      REAL*8          LAG,LIERS
      COMMON /EPAR/   R0,RE,GE,EROT,BL(0:2),GM,GRVLAT,ESQUAR,FE,BG
     &,               RHOW
      COMMON /COREP/  ONDR,QNDR,FREFC, SBTNDR(0:2),ZOTNDR(0:2)
      COMMON /WANGP/  PHI0(0:2),PHI1(0:2),P(0:2)
     &,               BRPER,FBR,F0,BSF,FCAL(0:2)
     &,               SUM2(0:2),ATTBSF(0:2),CFCBSF(0:2),VCAL(0:2)
     &,               LCALL(0:2),COMBSF,COMP(0:2)
      COMMON /WAHRP/  WWP0(0:2), WLP0(0:2), WZ0(0:2)
     &,               WY, WWP1, WLP1, WZ1, WS3, WKP0(0:2), WSLP(0:2)
      COMMON /SHDOP/  CORDH(2:4,0:4), CORDL(2:4,0:4), CORDK(2:4,0:4)

      SAVE
      
      DATA WANEL/'ANEL'/, WCORE/'NDR '/, WSHDO/'SHDO'/, WIERS/'IERS'/
     &,    WWAHR/'WAHR'/
C
c      print *,' <SHOW_P>>> pi, rad: ',pi,rad
      IF (WHAT.EQ.WIERS)  THEN
         PRINT 1031, WHAT
         PRINT 1032, HIERS,DLQCK1,LIERS,LAG/RAD
         PRINT 1004
      ELSE IF (WHAT.EQ.WANEL) THEN
         PRINT 1001, WHAT
         PRINT 1003, BSF/RAD,COMBSF,BRPER,F0/RAD
     &,              (FCAL(I)/RAD,VCAL(I),I=0,2)
         PRINT 1004
         PRINT 1002, (COMP(I),PHI0(I)/RAD,P(I),I=0,2)
         PRINT 1004
      ELSE IF (WHAT.EQ.WCORE) THEN
         PRINT 1011, WHAT
         PRINT 1012, ONDR,QNDR,FREFC/RAD,(SBTNDR(I),ZOTNDR(I),I=0,2)
      ELSE IF (WHAT.EQ.WSHDO) THEN
         PRINT 1021, WHAT
         PRINT 1023, 'H',BL(0)
         DO 21 I=2,4
21       PRINT 1022, I,(CORDH(I,J),J=0,I)
         PRINT 1004
         PRINT 1999
         PRINT 1023, 'L',BL(1)
         DO 22 I=2,4
22       PRINT 1022, I,(CORDL(I,J),J=0,I)
         PRINT 1004
         PRINT 1999
         PRINT 1023, 'K',BL(2)
         DO 23 I=2,4
23       PRINT 1022, I,(CORDK(I,J),J=0,I)
         PRINT 1004
      ELSE IF (WHAT.EQ.WWAHR) THEN
         PRINT 1041, WHAT
         PRINT 1042
         PRINT 1043,'W+0 ',WWP0
         PRINT 1043,'L+0 ',WLP0
         PRINT 1043,'Z0  ',WZ0
         PRINT 1043,'Y   ',WY
         PRINT 1043,'S3  ',WS3
         PRINT 1004
         PRINT 1045
         PRINT 1044,'W+1 ',WWP1
         PRINT 1044,'L+1 ',WLP1
         PRINT 1044,'Z1  ',WZ1
         PRINT 1043,'K+0 ',WKP0
         PRINT 1043,'WSlp',WSLP
      ELSE
         PRINT '(2A)',' <Show_P>W> Unknown parameter set identifier '
     &,  WHAT
      ENDIF
      RETURN
1999  FORMAT (' <Show_P>>>')
1001  FORMAT ('0<Show_P ',A4,'>>> ZSCHAU AND WANG''S (1986)'
     &, ' ANELASTICITY MODEL '/' <Show_P>>>')
1003  FORMAT (' <Show_P>>> Basic frequency ',T35,F10.6,' deg/h:   ',A12/
     &        ' <Show_P>>> Breakpoint period ',T33,F7.1,7X,' y'/
     &        ' <Show_P>>> Reference frequency',T35,F10.6,' deg/h'/
     &        ' <Show_P>>> Calibration H:',T35,F10.6,' deg/h:'
     &,       ' relaxation',T65,F10.5/
     &        ' <Show_P>>>             L:',T35,F10.6,' deg/h:'
     &,              T65,F10.5/
     &        ' <Show_P>>>             K:',T35,F10.6,' deg/h:'
     &,              T65,F10.5/
     &        ' <Show_P>>>'/
     &        ' <Show_P>>>  Component   Phase at Ref_Freq.   Power law'/
     &        ' <Show_P>>>                     (deg)         for phase')
1002  FORMAT (' <Show_P>>> ',A12,F13.3,10X,F8.4)
1004  FORMAT (' <Show_P>>> -------------------------------------------')
C
1011  FORMAT ('0<Show_P ',A4,'>>> LIQUID CORE RESONANCE PARAMETERS '/
     &        ' <Show_P>>>')
1012  FORMAT (' <Show_P>>> Period offset from siderial day: 1 cyc /'
     &,  F6.1,' d, Q =',F7.1/
     &        ' <Show-P>>> Reference freq. f. NDR-formulas:',F10.6,
     &' deg/h'/' <Show_P>>>'/
     &        ' <Show_P>>> Strength parameters'/
     &        ' <Show_P>>> Component      Earth    Re..Earth-ocean..Im'/
     &        ' <Show_P>>> -------------------------------------------'/
     &        ' <Show_P>>> Radial      ',1P,D9.2,2D11.2/
     &        ' <Show_P>>> Tangential  ',1P,D9.2,2D11.2/
     &        ' <Show_P>>> Potential   ',1P,D9.2,2D11.2/
     &        ' <Show_P>>> -------------------------------------------')
C
1021  FORMAT ('0<Show_P ',A4,'>>> LOVE NUMBER RATIOS LN(n,m) / LN(2,1)'/
     &        ' <Show_P>>>')
1022  FORMAT (' <Show_P>>>',I2,2X,5F8.4)
1023  FORMAT (' <Show_P>>> Basic Love number ',A1,'(2,1): ',F8.4/
     &        ' <Show_P>>>'/
     &        ' <Show_P>>> n    /__________ m = 0, ... , n __________/'/
     &        ' <Show_P>>> -------------------------------------------')
C
1031  FORMAT ('0<Show_P ',A4,'>>> SIMULATION OF CALC / IERS:'/
     &        ' <Show_P>>>')
1032  FORMAT (' <Show_P>>> Love number h        ',F10.6
     &,                           ', diff.at K1 ',F10.6/
     &        ' <Show_P>>> Love number l        ',F10.6/
     &        ' <Show_P>>> Tide bulge lag angle ',F10.6,' (deg)')
C
1041  FORMAT ('0<Show_P ',A4,'>>> WAHR''S DISPLACEMENT/STRAIN PARAMETERS
     &'/' <Show_P>>>')
1042  FORMAT (' <Show_P>>> P    /__________ m = 0, ... , 2 __________/'/
     &        ' <Show_P>>> -------------------------------------------')
1043  FORMAT (' <Show_P>>> ',a4,3f10.6)
1044  FORMAT (' <Show_P>>> ',a4,10X,f10.6)
1045  FORMAT (' <Show_P>>>      Resonance strengths:')
C
C ---------------------------------------- IERS (IERSPA):
      ENTRY IERSLG (F)
C UTIDE P/S * Set lag for IERS-Earth
      LAG=F*RAD
      RETURN
      ENTRY GET_IERSLG (F)
C UTIDE P/S * Get lag for IERS-Earth
      F=LAG/RAD
      RETURN
C
      ENTRY IERSH  (F)
C UTIDE P/S * Set Love-h for IERS-Earth
      HIERS=F
      RETURN
      ENTRY GET_IERSH (F)
C UTIDE P/S * Get Love-h for IERS-Earth
      F=HIERS
      RETURN
C
      ENTRY IERSL (F)
C UTIDE P/S * Set Love-l for IERS-Earth
      LIERS=F
      RETURN
      ENTRY GET_IERSL (F)
C Parameter setting * Get Love-l for IERS-Earth
      F=LIERS
      RETURN
C
      ENTRY IERSDH (F)
C UTIDE P/S * Set delta Love-h @ K1 for IERS-Earth
      DLQCK1=F
      RETURN
      ENTRY GET_IERSDH (F)
C UTIDE P/S * Get delta Love-h @ K1 for IERS-Earth
      F=DLQCK1
      RETURN
C
C ---------------------------------------- AEL (WANGP):
C
      ENTRY AELBSF (F,COMM)
C UTIDE P/S * Set basic frequency for anelastic relax.model
      BSF=F
      COMBSF=COMM
      LCALL(1)=.TRUE.
      LCALL(2)=.TRUE.
      LCALL(0)=.TRUE.
      RETURN
C
      ENTRY AELF0  (F)
C UTIDE P/S * Set reference frequency for anelastic relax.model
      F0=F
      LCALL(1)=.TRUE.
      LCALL(2)=.TRUE.
      LCALL(0)=.TRUE.
      RETURN
C
      ENTRY AELCAL (L,F,G)
C UTIDE P/S * Set calib.frequ. & value for anelast. relax.model
      FCAL(L)=F
      VCAL(L)=G
      LCALL(L)=.TRUE.
      RETURN
      ENTRY GET_AELCAL (L,F,G)
C UTIDE P/S * Get calib.frequ. & value for anelast. relax.model
      F=FCAL(L)
      G=VCAL(L)
      RETURN
C
      ENTRY AELPH0 (L,F)
C UTIDE P/S * Set phase at basic frequency for anelastic model
      PHI0(L)=F
      LCALL(L)=.TRUE.
      RETURN
      ENTRY GET_AELPH0 (L,F)
C UTIDE P/S * Get phase at basic frequency for anelastic model
      F=PHI0(L)
      RETURN
C
      ENTRY AELBRP (F)
C UTIDE P/S * Set breakpoint period for anelastic model
      BRPER=F
      LCALL(1)=.TRUE.
      LCALL(2)=.TRUE.
      LCALL(0)=.TRUE.
      RETURN
      ENTRY GET_AELBRP (F)
C UTIDE P/S * Get breakpoint period for anelastic model
      F=BRPER
      RETURN
C
      ENTRY AELPWP (L,F)
C UTIDE P/S * Set phase power law for anelastic model
      P(L)=F
      LCALL(L)=.TRUE.
      RETURN
      ENTRY GET_AELPWP (L,F)
C UTIDE P/S * Get phase power law for anelastic model
      F=P(L)
      RETURN
C
C ---------------------------------------- NDR (COREP):
C
      ENTRY NDRFRQ (F)
C UTIDE P/S * Set NDR beat period
      ONDR=F
      RETURN
      ENTRY GET_NDRFRQ (F)
C UTIDE P/S * Get NDR beat preriod
      F=ONDR
      RETURN
C
      ENTRY NDRREF (F)
C UTIDE P/S * Set NDR reference frequency
      FREFC=F
      RETURN
      ENTRY GET_NDRREF (F)
C UTIDE P/S * Get NDR reference frequency
      F=FREFC
      RETURN
C
      ENTRY NDRQUA (F)
C UTIDE P/S * Set NDR quality
      QNDR=F
      RETURN
      ENTRY GET_NDRQUA (F)
C UTIDE P/S * Get NDR quality
      F=QNDR
      RETURN
C
      ENTRY GET_NDRZFR (Z)
C UTIDE P/S * Get NDR frequency
      FRENDR=(1.D0+1.D0/ONDR)*EROT
      Z=DCMPLX(FRENDR,FRENDR/2.D0/QNDR)
      RETURN
C
      ENTRY NDRBTS (L,F)
C UTIDE P/S * Set NDR strength body tide
      SBTNDR(L)=F
      RETURN
      ENTRY GET_NDRBTS (L,F)
C UTIDE P/S * Get NDR strength body tide
      F=SBTNDR(L)
      RETURN
C
      ENTRY NDROSE (L,Z)
C UTIDE P/S * Set NDR strength ocean loading tide
      ZOTNDR(L)=Z
      RETURN
      ENTRY GET_NDROSE (L,Z)
C UTIDE P/S * Get NDR strength ocean loading tide
      Z=ZOTNDR(L)
      RETURN
C
C ---------------------------------------- ORD ( SHDO / EPAR ):
C
      ENTRY SHDOH (K,L,F)
C UTIDE P/S * Set spherical harmonic coupling Love h
      CORDH(K,L)=F
      RETURN
      ENTRY GET_SHDOH (K,L,F)
C UTIDE P/S * Get spherical harmonic coupling Love h
      F=CORDH(K,L)
      RETURN
C
      ENTRY SHDOL (K,L,F)
C UTIDE P/S * Set spherical harmonic coupling Love l
      CORDL(K,L)=F
      RETURN
      ENTRY GET_SHDOL (K,L,F)
C UTIDE P/S * Get spherical harmonic coupling Love l
      F=CORDL(K,L)
      RETURN
C
      ENTRY SHDOK (K,L,F)
C UTIDE P/S * Set spherical harmonic coupling Love k
      CORDK(K,L)=F
      RETURN
      ENTRY GET_SHDOK (K,L,F)
C Parameter setting * Get spherical harmonic coupling Love k
      F=CORDK(K,L)
      RETURN
C
      ENTRY SHDOBL (L,F)
C UTIDE P/S * Set Basic Love number
      BL(L)=F
      RETURN
      ENTRY GET_SHDOBL (L,F)
C UTIDE P/S * Get Basic Love number
      F=BL(L)
      RETURN

C 
      ENTRY GET_POLETIDE_COEFFICIENT (F)
c
c Meters equilibrium tide on elastic earth per second of arc pole offset
c To obtain the field, you must multiply with -P_{21}(colat) e^{-i longitude}
      F=(R0*EROT/3.6d3)**2*RAD/3.6d3/3d0/9.81d0*(1.d0+BL(2)-BL(0))
      RETURN

C
      ENTRY WAHRPM (KIND,L,F)
C UTIDE P/S * Set Wahr parameters (W+)0 (W+)1 (L+)0 Z0 Z1 Y S3 (K+)0
      IF (INDEX('W0w0',KIND).GT.0) THEN
         WWP0(L)=F
      ELSEIF (INDEX('L0l0',KIND).GT.0) THEN
         WLP0(L)=F
      ELSEIF (INDEX('Z0z0',KIND).GT.0) THEN
         WZ0(L)=F
      ELSEIF (INDEX('Yy',KIND(1:1)).GT.0) THEN
         WY=F
      ELSEIF (INDEX('Z1z1',KIND).GT.0) THEN
         WZ1=F
      ELSEIF (INDEX('L1l1',KIND).GT.0) THEN
         WLP1=F
      ELSEIF (INDEX('W1w1',KIND).GT.0) THEN
         WWP1=F
      ELSEIF (INDEX('S3s3',KIND).GT.0) THEN
         WS3=F
      ELSEIF (INDEX('K+k+',KIND).GT.0) THEN
         WKP0(L)=F
      ELSEIF (INDEX('WSwsLPlp',KIND).GT.0) THEN
         WSLP(L)=F
      ENDIF
      RETURN
      ENTRY GET_WAHRPM (KIND,L,F)
C UTIDE P/S * Get Wahr parameters
      IF (INDEX('W0w0',KIND).GT.0) THEN
         F=WWP0(L)
      ELSEIF (INDEX('L0l0',KIND).GT.0) THEN
         F=WLP0(L)
      ELSEIF (INDEX('Z0z0',KIND).GT.0) THEN
         F=WZ0(L)
      ELSEIF (INDEX('Yy',KIND(1:1)).GT.0) THEN
         F=WY
      ELSEIF (INDEX('Z1z1',KIND).GT.0) THEN
         F=WZ1
      ELSEIF (INDEX('L1l1',KIND).GT.0) THEN
         F=WLP1
      ELSEIF (INDEX('W1w1',KIND).GT.0) THEN
         F=WWP1
      ELSEIF (INDEX('S3s3',KIND).GT.0) THEN
         F=WS3
      ELSEIF (INDEX('K+k+',KIND).GT.0) THEN
         F=WKP0(L)
      ELSEIF (INDEX('WSwsLPlp',KIND).GT.0) THEN
         F=WSLP(L)
      ENDIF
      RETURN
      END
C
C
C     -------------------------------
      REAL*8 FUNCTION GET_EPAR (WHAT)
C UTIDE P/S * retrieve earth parameters
C     -------------------------------
      IMPLICIT REAL*8 (A-H,O-Z)
      CHARACTER WHAT*(*),WH*33
      COMMON /EPAR/   R0,RE,GE,EROT,BL(3),GM,GRVLAT,ESQUAR,FE,BG
     &,               RHOW
      SAVE
C
      IF (INDEX(WHAT,'|').GT.0) GOTO 101
      LW=INDEX(WHAT,' ')
      IF (LW.LE.0) LW=LEN(WHAT)
      LW=MIN0(32,LW)
      CALL UCASE(WHAT(:LW),WH(2:))
      LW=LW+1
      WH(1:1)='|'
      IF (INDEX('|R0|RMEAN|R_MEAN|R_0',WH(:LW)).GT.0) THEN
         IF (LW.LT.3) GOTO 102
         GET_EPAR=R0
      ELSEIF (INDEX('|REQUATORIAL|R_EQUATORIAL',WH(:LW)).GT.0) THEN
         IF (LW.LT.3) GOTO 102
         GET_EPAR=RE
      ELSEIF (INDEX('|GEQUATORIAL|G_EQUATORIAL',WH(:LW)).GT.0) THEN
         IF (LW.LT.3) GOTO 102
         GET_EPAR=GE
      ELSEIF (INDEX('|EROTATION|EARTHROTATION|E_ROTATION|EARTH_ROTATION'
     &, WH(:LW)).GT.0) THEN
         IF (INDEX(WH,'ROT').LT.0) GOTO 102
         IF (LW.LT.5) GOTO 102
         GET_EPAR=EROT
      ELSEIF (INDEX('|BLH|BL_H|LOVE_H',WH(:LW)).GT.0) THEN
         IF (LW.LT.4) GOTO 102
         IF (INDEX(WH,'H').LT.0) GOTO 102
         GET_EPAR=BL(1)
      ELSEIF (INDEX('|BLL|BL_L|LOVE_L',WH(:LW)).GT.0) THEN
         IF (LW.LT.4) GOTO 102
         IF (INDEX(WH,'L').LT.0) GOTO 102
         GET_EPAR=BL(2)
      ELSEIF (INDEX('|BLK|BL_K|LOVE_K',WH(:LW)).GT.0) THEN
         IF (LW.LT.4) GOTO 102
         IF (INDEX(WH,'K').LT.0) GOTO 102
         GET_EPAR=BL(3)
      ELSEIF (INDEX('|GM|G_M|G*M',WH(:LW)).GT.0) THEN
         IF (LW.LT.3) GOTO 102
         GET_EPAR=GM
      ELSEIF (INDEX('|GRVLAT|GRAVLATITUDE|GRAV_LATITUDE'
     &, WH(:LW)).GT.0) THEN
         IF (LW.LT.5) GOTO 102
         IF (INDEX(WH,'LAT').LT.0) GOTO 102
         GET_EPAR=GRVLAT
      ELSEIF (INDEX('|ESQUARE|E^2|E**2',WH(:LW)).GT.0) THEN
         IF (LW.LT.4) GOTO 102
         GET_EPAR=ESQUAR
      ELSEIF (INDEX('|1/FE|ELLIPTICITY',WH(:LW)).GT.0) THEN
         IF (LW.LT.5) GOTO 102
         GET_EPAR=FE
      ELSEIF (INDEX('|FLATTENING',WH(:LW)).GT.0) THEN
         IF (LW.LT.5) GOTO 102
         GET_EPAR=1./FE
      ELSEIF (INDEX('|BIGG|GRAVC|BIG_G',WH(:LW)).GT.0) THEN
         IF (LW.LT.5) GOTO 102
         GET_EPAR=BG
      ELSEIF (INDEX('|RHOWATER|RHO_WATER|RHO_SEAWATER',WH(:LW))
     &       .GT.0) THEN
         IF (LW.LT.5) GOTO 102
         GET_EPAR=RHOW
      ELSE
         GOTO 104
      ENDIF
      RETURN
101   PRINT '(A)',' <GeEpar>T> String contains "|"'
      GOTO 109
102   PRINT '(A)',' <GeEpar>T> String ambiguous'
      GOTO 109
104   PRINT '(3A)',' <GeEpar>T> Unknown ->',WH(:LW),'<-'
109   STOP
      END
C
C
C     ----------------
      BLOCK DATA B_PAR
C UTIDE P/S * Default earth parameters
C     ----------------
C>
C Initializes the following parameters:                    Named Common
C
C ----------- Mathematics constants --------------------------- MPAR ---
C -> moved to bmpar.f
C PI     *
C RAD    * = PI/180.
C
C ----------- Standard earth parameters ----------------------- EPAR ---
C
C R0, RE * mean and equatorial radius of the earth
C GE     * equatorial normal gravity
C EROT   * siderial earth rotation rate (rad/h)
C BL(3)  - Basic Love numbers h,l,k
C GM     * Grav.const.*Earth mass
C GRVLAT * Coefficient for latitude variation of normal gravity
C ESQUAR * Earth ellipsoid square eccentricity
C FE     * Inverse of earth flattening
C ______________________________________________________________________
C
C ----------- Anelastic model --------------------------------- WANGP --
C
C i=1: radial displ., i=2: tangential displ., i=3: second.potential
C PHI0(i)  - Phase shift at reference frequency
C P(i)     - Phase versus frequency = power law:
C            Phase(i) = (Freq./Ref_Freq.)**P(i)
C BRPER    - Phase model = power law above breakpoint frequency.
C            Breakpoint_Freq. = Ref_Freq. / BRPER
C F0       - Reference Frequency
C FBSF     - Basic frequency to which the Basic Love numbers refer.
C LCALL    - Signals whether constants have to be (re-)computed
C COMBSF   - 12 characters of comment for FBSF
C ______________________________________________________________________
C
C ----------- Core resonance model ---------------------------- COREP --
C
C ONDR     - Frequency parameter of the resonance,
C            ONDR = Resnc_Freq/(Resnc_Freq - siderial rotat.rate)
C QNDR     - Quality
C SEHNDR   - Resonance strength, solid earth tide part, Love n. H
C SELNDR   - ... Love n. L
C SEKNDR   - ... Love n. K
C ZOHNDR   - ... ocean-earth tide interaction part, Love n. H
C ZOLNDR   - ... Love n. L
C ZOKNDR   - ... Love n. K
C ______________________________________________________________________
C
C ----------- Spherical harmonic coupling model --------------- WAHRP --
C
C Elliptic earth; tide parameters from Wahr (1981), recast according
C to Scherneck, 1991. WAHRP contains only the SH-coupling parameters.
C The parameters associated with h and l are found in SHDOP and COREP.
C
C COMMON /WAHRPM/                                      (GET_)WAHRPM
C variable                                                 code
C ----------------------------------------------------------------------
C WWP0     * mean value of w+ for m=0..2                   'W0'
C WLP0     *  "     "   "  l+  "    "                      'L0'
C WZ0      *  "     "   "  z   "    "                      'Z0'
C WY       *  "     "   "  y, which is independent of m    'Y'
C WWP1     * scaled resonance strength of w+ for m=1       'W1'
C WLP1     *   "        "         "    "  l+  "   "        'L1'
C WZ1      *   "        "         "    "  z   "   "        'Z1'
C WKP0     * mean value of k+ for m=0..2                   'K0'
C WKP1     i scaled resonance strength of k+ is ignored (it's 20% of WKP0)
C WSLP     * Wahr&Sasao NDR response parameter due to ocean loading 
C            for Formula (2.6) in Scherneck (1991)         'WS'|'LP'
C ______________________________________________________________________
C
C ----------- IERS / CALC simulation ------------------------- IERSPA --
C
C HIERS    - Love number h
C DLQCK1   - Difference h(K1) - h
C LIERS    - Love number l
C LAG      - "Lag-angle"
C ______________________________________________________________________
C
C The parameters marked * are fixed; the others can be redefined using
C the entries in SHOW_PRM.
C_
      IMPLICIT REAL*8 (A-H,O-Y), COMPLEX*16 (Z)
      CHARACTER*12    COMBSF,COMP
      LOGICAL         LCALL
      REAL*8          LAG, LIERS
      COMMON /WAHRP/  WWP0(0:2), WLP0(0:2), WZ0(0:2)
     &,               WY, WWP1, WLP1, WZ1, WS3, WKP0(0:2), WSLP(0:2)
      COMMON /WANGP/  PHI0(0:2), PHI1(0:2), P(0:2)
     &,               BRPER, FBR, F0, BSF, FCAL(0:2)
     &,               SUM2(0:2), ATTBSF(0:2), CFCBSF(0:2), VCAL(0:2)
     &,               LCALL(0:2), COMBSF, COMP(0:2)
      COMMON /COREP/  ONDR, QNDR, FREFC
     &,               SEHNDR, SELNDR, SEKNDR, ZOHNDR, ZOLNDR, ZOKNDR
      COMMON /SHDOP/  CORDH(2:4,0:4), CORDL(2:4,0:4), CORDK(2:4,0:4)
      COMMON /EPAR/   R0,RE,GE,EROT,BL(3),GM,GRVLAT,ESQUAR,FE,BG,RHOW
      COMMON /IERSPA/ HIERS, DLQCK1, LIERS, LAG
C
C ------------------------------------------------ EPAR:
      DATA R0    / 6.371000  D6/             ! Mean radius [m] from RE and FE
     &,    RE    / 6.378137  D6/             ! Equatorial radius IERS Standards
     &,    GE    / 9.798529  D0/
     &,    EROT  / 0.26251614D0/             ! rad/h
     &,    BL    / 0.6030    D0, 0.0841   D0, 0.298   D0/
     &,    GM    / 3.98600440   D14/
     &,    GRVLAT/ 1.93166338321D-3/
     &,    ESQUAR/ 6.69438   D-3/            ! from FE
CCC  &,    ESQUAR/ 6.69460532856D-3/         ! scnd. ecc
     &,    FE    / 0.298257  D3/             ! first ecc IERS-Standards
     &,    BG    / 6.6725985 D-11/           ! Newton G  m^3/kg/s^2
     &,    RHOW  / 1.03      D3/             ! Density sea water kg/m^2
C
C ------------------------------------------------ WAHRP
      DATA WWP0  / 0.00D00,  0.00D00,  5.3 D-4/
     &,    WLP0  /-2.7 D-3, -1.4 D-3, -1.2 D-4/
     &,    WZ0   / 1.40D-2,  1.39D-2,  1.40D-2/
     &,    WY    / 1.0 D-3/
     &,    WZ1   /-7.2 D-2/
     &,    WLP1  / 1.1 D-2/
     &,    WWP1  /-4.4 D-3/
     &,    WS3   / 1.0 D-3/
     &,    WKP0  /-6.7 D-3, -3.7 D-3, -0.33D-3/
     &,    WSLP  /-2.88D-4,  9.16D-6, -1.45D-4/
C
C ------------------------------------------------ IERSPA
      DATA HIERS / 0.60967      D00/
     &,    DLQCK1/-0.0887       D00/
     &,    LIERS / 0.085        D00/
     &,    LAG   / 0.0          D00/
C
C ------------------------------------------------ WANGP:
      DATA PHI0  /-1.279   D-2, -5.765  D-2, -1.679  D-2/
     &,    P     /-0.2218  D00, -0.2945 D00, -0.2292 D00/
     &,    BRPER / 1.0     D+2/
     &,    F0    / 7.16768 D-4/
     &,    BSF   / 0.505868D00/
     &,    FCAL /3*1.916424D-2/
     &,    VCAL  / 1.025   D00, 1.075   D00, 1.0143  D00/
     &,    COMBSF/'   M2-tide  '/
     &,    SUM2  /3*    0.0D0 /
     &,    LCALL /3*  .TRUE.  /
     &,    COMP  /'Radial      ','Tangential  ','SecPotential'/
C
C ------------------------------------------------ COREP:
      DATA ONDR  / 434.2 D00/
     &,    QNDR  /   2.76D03/
     &,    FREFC /0.243351886D00/
     &,    SEHNDR/   4.08D-3/
     &,    SELNDR/  -0.9 D-3/
     &,    SEKNDR/   4.13D-3/
     &,    ZOHNDR/ (-10.6D-6,-10.7D-6)/
     &,    ZOLNDR/ (  2.4D-6,  2.4D-6)/
     &,    ZOKNDR/ (-10.8D-6,-10.9D-6)/
C
c dH    1.0620D-05  1.0709D-05    1.5082D-05     45.2
c dL   -2.4218D-06 -2.4422D-06    3.4394D-06    225.2
c dK    1.0819D-05  1.0910D-05    1.5365D-05     45.2
C ------------------------------------------------ SHDOP:
      DATA  ((CORDH(I,J),J=0,I),I=2,4)
     &     /1.005D0,1.0D0,1.010D0,4*0.479D0,5*0.2861D0/
      DATA  ((CORDL(I,J),J=0,I),I=2,4)
     &     /1.012D0,1.0D0,0.998D0,4*0.172D0,5*0.1238D0/
      DATA  ((CORDK(I,J),J=0,I),I=2,4)
     &     /3*1.0D0,4*0.3099D0,5*0.1411D0/
      END
