      logical function q_index (str1,str2,iq)
c Strings * logical index function
c>
c Returns true if str2 is a substring of str1, and iq its position
c_
      character str1*(*),str2*(*)
      iq=index(str1,str2)
      q_index=iq.gt.0
      return
      end

      logical function qu_index (str1,str2,iq,qc)
c Strings * logical index function
c>
c Returns true if str2 is a substring of str1, and iq its position
c Ignores case of str1. Therefore:
c str2 must be upper case on call !
c Limitation: str2 max 32 length 
c_
      character str1*(*),str2*(*), str3*32
      logical q,qc,q_index
      
      iq = index(str1,str2)
       q = iq.gt.0
      qu_index = q
      if (q.or..not.qc) return
      
      l1=len(str1)
      l2=min0(len(str2),32)
      if (l2.gt.l1) return

      do i=1,l1,33-l2
         str3=str1(i:i+31)
         l3=min0(32,l1-i+1)
         call ucase (str3,str3)
         if (q_index(str3(:l3),str2(:l2),iq)) then
            iq=iq+i-1
            qu_index=.true.
            return
         endif
      enddo

      return
      end

      logical function qor_index (str1,str2,iq)
c Strings * logical function index(str1,str2(j:j)), j=1..length
c>
c Returns true if any character of str2 is in str1.
c iq is the position of the first character of str2 that also is in str1.
c_
      character str1*(*),str2*(*)
      logical q, q_index
      q=.false.
      l2=len(str2)
      iq=0
101   iq=iq+1
      q=q.or.q_index(str1,str2(iq:iq),j)
      if ((.not.q).and.iq.lt.l2) goto 101
      qor_index = q
      if (.not.q) iq=0
      return
      end

      logical function ql_index (str1,str2,ip)
c Strings * logical function index(str1,str2(j:j)), j=1..length
c>
c Returns true if any character of str2 is in str1.
c ip is the position of the first character of str1 that also is in str2.
c_
      character str1*(*),str2*(*)
      logical q, q_index
      q=.false.
      l2=len(str2)
      iq=0
101   iq=iq+1
      q=q.or.q_index(str1,str2(iq:iq),j)
      if ((.not.q).and.iq.lt.l2) goto 101
      ql_index = q
      if (q) then
         ip=index(str1,str2(iq:iq))
      else
         ip=0
      endif
      return
      end

      integer function ior_index (str1,str2,iq)
      character str1*(*),str2*(*)
      logical qor_index,q
      q=qor_index (str1,str2,iq)
      if (iq.gt.0) then
         ior_index=index(str1,str2(iq:iq))
      else
         ior_index=0
      endif
      return
      end

      logical function quch_in (ch,str,i)
c Strings * logical function ucase(ch) == element of ucase(str)
c>
c Returns true if UCASE$(ch) is in UCASE$(str). Returns position in I
c
c CH - char** - less than 32 long
c_
      character ch*(*), str*(*), tch*32, tstr*32

      quch_in=.false.
      i=0
      lch=len(ch)
      lstr=len(str)
      if (lch.gt.lstr) return
      if (lch.eq.0) then
         quch_in=.true.
         return
      elseif (lch.eq.1) then
         if (ichar(ch(1:1)).lt.32) then
            quch_in=.true.
            return
         endif
      endif
      lch=min0(32,lch)

      tch=ch(:lch)
      call ucase (tch(:lch),tch)
      l=lch-1
      do 101 j=1,lstr-l
      call ucase (str(j:j+l),tstr)
c      print *,' >q> ->',str(j:j+1),'<->',tch(:lch),'<-'
      if (tstr(:lch).eq.tch(:lch)) then
         i=j
         quch_in=.true.
         return
      endif
101   continue
      return
      end

      logical function qucss (a,str,delim,ia,ja,is)
c Strings * Like quch_in, find delimited substrings of a in str
c>
c Example:
c qucss('a|b|cde|fg',STRING,'|',IA,JA,IS)
c returns .true.  if 'a' in STRING or 'A' in string
c                 or 'b' ...
c                        ... or 'FG' in string
c
c A        - char**  - delimited list of codewords .
c DELIM    - char*1  - delimiter
c IA,JA,IS - integer - string positions, returned.
c
c IA,JA,IS : while resolving delimiters, set  SUBSTRING := A(IA:JA).
c First encounter  IS := index(STRING,SUBSTRING)
c
c That means: If qucss returns .true., codeword A(IA:JA) has been found 
c in STRING at position IS.
c_
      character a*(*),str*(*),delim*1
      logical q,quch_in
      q=.false.
      la=index_l_nonblank(a)
      k=1
      is=0
      ia=la+1
      ja=la

1     l=index(a(k:),delim)+k-2
      if (l.lt.k) l=la
      ll=l-k+1
      if (ll.gt.0) then
         q = quch_in (a(k:l),str,j)
         if (q) then
            qucss=.true.
            is=j
            ia=k
            ja=l
            return
         endif
      endif
      k=l+2
      if (k.gt.la) then
         qucss=.false.
         return
      endif
      goto 1
      end

      logical function q_substring (buff,prm,delims,word,lp,lw)
c Strings * Extract an indicated word from a string 
c
c buff   - char** - Input string. 
c prm    - char** - The left delimiter, e.g. ' P=', taking the role of the
c                   name of a parameter.
c             '^' - special value: return the first part of buff up to
c                   one of the indicated delimiters. 
c delims - char** - A collection of possible right delimiters. If none can be
c                   found the whole part of buff after 'P=' is returned. 
c                   The delimiter list is processed left-to-right, escaped
c                   at first encounter. 
c word   - char** - The indicated substring, returned.
c ip     - integer- its starting position, returned.
c lw     - integer- its length, returned.
c                   -9999 on call: the 'word' is the shortest possible within 
c                                  the given 'prm' 'delims'.
c                            else: the 'word' is decided by the earliest 
c                                  element of 'delims' that is found beyond
c                                  'prm' in 'buff'. 
c
c Iff prm is not found in buff then q_substring is returned .false.
c Also, the returned parameters are unaffected.
c
c Example: Let buff='lmnxyz P=abcxyz] L=mnoxyz] M=fghxyz$'
c
c q_substring (buff,'P=',']',word,ip,iw) returns .true. and
c              word -> 'abcxyz', ip -> 10, iw -> 6
c
c q_substring (buff,'P=','$',word,ip,iw) returns .true. and
c              word -> 'abcxyz] L=mnoxyz] M=fghxyz', ip -> 10, iw -> 26
c
c q_substring (buff,'R=','$',word,ip,iw) returns .false. 
c
c
c Example:
c This section of code replaces environment variable sybols in a string
c by their value, using UNIX system function getenv:
c 
c 188  j=-9999
c      if (q_substring(rstr,'${','} ',envstr,i,j)) then
c         lei=index(envstr//' ',' ')-1
c         call getenv (envstr(:lei),envout)
c         leo=index(envout//' ',' ')-1
c         call replace_in_string 
c     &       (rstr,'${'//envstr(:lei)//'}',envout(:leo),i-2,0)
c         goto 188
c      endif
c 189  j=-9999
c      if (q_substring(rstr,'$','./$- ',envstr,i,j)) then
c         lei=index(envstr//' ',' ')-1
c         call getenv (envstr(:lei),envout)
c         leo=index(envout//' ',' ')-1
c         call replace_in_string 
c     &           (rstr,'$'//envstr(:lei),envout(:leo),i-1,0)
c         goto 189
c      endif
c
c _ end example
c
      character buff*(*), prm*(*), delims*(*), word*(*), s*1
      logical q, qe, qu_index, qu_substring
      qe=.false.
      goto 1

      entry qu_substring (buff,prm,delims,word,lp,lw)
      qe=.true.
 1    lprm=len(prm)
      if (prm.eq.'^') then
         ip=1
         q=.true.
         lprm=0
      else
         q=qu_index(buff,prm,ip,qe)
      endif
      kwm=len(buff)
      if (q) then
         ip=ip+lprm
         lp=ip
         l=len(delims)
         do 101 i=1,l
            s=delims(i:i)
            kw=index(buff(ip:),s)+ip-2
ccccccccccccccccccccccccccccccccccccccccccc new:
            if (kw.gt.ip-2) then
               if (lw.eq.-9999) then
                  kwm=min0(kwm,kw)
               else
                  kwm=kw
                  goto 102
               endif
            endif
c ccccccccccccccccccccccccccc old:   if (kw.gt.ip-2) goto 102
 101     continue
c ccccccccccccccccccccccccccc old:     kwm=len(buff)
 102  word=buff(ip:kwm)
      lw=min0(len(word),kwm-ip+1)        
      endif
      if (qe) then
         qu_substring=q
      else
         q_substring=q
      endif
      kw=kwm
      return
      end
      
      
C:Provides  integer function ior_index F=stringf.f
